# gengive

Render text (Danish: gengive tekst).

[License: MIT](https://git.sr.ht/~sthagen/gengive/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/gengive.svg?style=flat)](https://pypi.python.org/pypi/gengive/)
[![downloads](https://pepy.tech/badge/gengive/month)](https://pepy.tech/project/gengive)
[![wheel](https://img.shields.io/pypi/wheel/gengive.svg?style=flat)](https://pypi.python.org/pypi/gengive/)
[![supported-versions](https://img.shields.io/pypi/pyversions/gengive.svg?style=flat)](https://pypi.python.org/pypi/gengive/)
[![supported-implementations](https://img.shields.io/pypi/implementation/gengive.svg?style=flat)](https://pypi.python.org/pypi/gengive/)

## Documentation

User and developer [documentation of gengive](https://codes.dilettant.life/docs/gengive).

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of gengive](https://todo.sr.ht/~sthagen/gengive).

## Primary Source repository

The primary source repository of [gengive is at sourcehut](https://git.sr.ht/~sthagen/gengive)
a collection of tools useful for software development.

## Status

Experimental.

**Note**: The default branch is `default`.
